"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findOrCreateContainerLayer = exports.getPagesFromRange = exports.getPageFromElement = exports.asElement = exports.isHTMLCanvasElement = exports.isHTMLElement = exports.getWindow = exports.getDocument = void 0;
var getDocument = function (elm) {
    return (elm || {}).ownerDocument || document;
};
exports.getDocument = getDocument;
var getWindow = function (elm) {
    return ((0, exports.getDocument)(elm) || {}).defaultView || window;
};
exports.getWindow = getWindow;
var isHTMLElement = function (elm) {
    return elm instanceof HTMLElement || elm instanceof (0, exports.getWindow)(elm).HTMLElement;
};
exports.isHTMLElement = isHTMLElement;
var isHTMLCanvasElement = function (elm) {
    return elm instanceof HTMLCanvasElement ||
        elm instanceof (0, exports.getWindow)(elm).HTMLCanvasElement;
};
exports.isHTMLCanvasElement = isHTMLCanvasElement;
var asElement = function (x) { return x; };
exports.asElement = asElement;
var getPageFromElement = function (target) {
    var node = (0, exports.asElement)(target.closest(".page"));
    if (!node || !(0, exports.isHTMLElement)(node)) {
        return null;
    }
    var number = Number((0, exports.asElement)(node).dataset.pageNumber);
    return { node: node, number: number };
};
exports.getPageFromElement = getPageFromElement;
var getPagesFromRange = function (range) {
    var startParentElement = range.startContainer.parentElement;
    var endParentElement = range.endContainer.parentElement;
    if (!(0, exports.isHTMLElement)(startParentElement) || !(0, exports.isHTMLElement)(endParentElement)) {
        return [];
    }
    var startPage = (0, exports.getPageFromElement)((0, exports.asElement)(startParentElement));
    var endPage = (0, exports.getPageFromElement)((0, exports.asElement)(endParentElement));
    if (!(startPage === null || startPage === void 0 ? void 0 : startPage.number) || !(endPage === null || endPage === void 0 ? void 0 : endPage.number)) {
        return [];
    }
    if (startPage.number === endPage.number) {
        return [startPage];
    }
    if (startPage.number === endPage.number - 1) {
        return [startPage, endPage];
    }
    var pages = [];
    var currentPageNumber = startPage.number;
    var document = startPage.node.ownerDocument;
    while (currentPageNumber <= endPage.number) {
        var currentPage = (0, exports.getPageFromElement)(document.querySelector("[data-page-number='" + currentPageNumber + "'"));
        if (currentPage) {
            pages.push(currentPage);
        }
    }
    return pages;
};
exports.getPagesFromRange = getPagesFromRange;
var findOrCreateContainerLayer = function (container, className) {
    var doc = (0, exports.getDocument)(container);
    var layer = container.querySelector("." + className);
    if (!layer) {
        layer = doc.createElement("div");
        layer.className = className;
        container.appendChild(layer);
    }
    return layer;
};
exports.findOrCreateContainerLayer = findOrCreateContainerLayer;
//# sourceMappingURL=pdfjs-dom.js.map