var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { Component } from "react";
import { asElement, isHTMLElement } from "../lib/pdfjs-dom";
import "../style/MouseSelection.css";
var MouseSelection = /** @class */ (function (_super) {
    __extends(MouseSelection, _super);
    function MouseSelection() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            locked: false,
            start: null,
            end: null,
        };
        _this.reset = function () {
            var onDragEnd = _this.props.onDragEnd;
            onDragEnd();
            _this.setState({ start: null, end: null, locked: false });
        };
        return _this;
    }
    MouseSelection.prototype.getBoundingRect = function (start, end) {
        return {
            left: Math.min(end.x, start.x),
            top: Math.min(end.y, start.y),
            width: Math.abs(end.x - start.x),
            height: Math.abs(end.y - start.y),
        };
    };
    MouseSelection.prototype.componentDidUpdate = function () {
        var onChange = this.props.onChange;
        var _a = this.state, start = _a.start, end = _a.end;
        var isVisible = Boolean(start && end);
        onChange(isVisible);
    };
    MouseSelection.prototype.componentDidMount = function () {
        var _this = this;
        if (!this.root) {
            return;
        }
        var that = this;
        var _a = this.props, onSelection = _a.onSelection, onDragStart = _a.onDragStart, onDragEnd = _a.onDragEnd, shouldStart = _a.shouldStart;
        var container = asElement(this.root.parentElement);
        if (!isHTMLElement(container)) {
            return;
        }
        var containerBoundingRect = null;
        var containerCoords = function (pageX, pageY) {
            if (!containerBoundingRect) {
                containerBoundingRect = container.getBoundingClientRect();
            }
            return {
                x: pageX - containerBoundingRect.left + container.scrollLeft,
                y: pageY -
                    containerBoundingRect.top +
                    container.scrollTop -
                    window.scrollY,
            };
        };
        container.addEventListener("mousemove", function (event) {
            var _a = _this.state, start = _a.start, locked = _a.locked;
            if (!start || locked) {
                return;
            }
            that.setState(__assign(__assign({}, _this.state), { end: containerCoords(event.pageX, event.pageY) }));
        });
        container.addEventListener("mousedown", function (event) {
            if (!shouldStart(event)) {
                _this.reset();
                return;
            }
            var startTarget = asElement(event.target);
            if (!isHTMLElement(startTarget)) {
                return;
            }
            onDragStart();
            _this.setState({
                start: containerCoords(event.pageX, event.pageY),
                end: null,
                locked: false,
            });
            var onMouseUp = function (event) {
                var _a;
                // emulate listen once
                (_a = event.currentTarget) === null || _a === void 0 ? void 0 : _a.removeEventListener("mouseup", onMouseUp);
                var start = _this.state.start;
                if (!start) {
                    return;
                }
                var end = containerCoords(event.pageX, event.pageY);
                var boundingRect = that.getBoundingRect(start, end);
                if (!isHTMLElement(event.target) ||
                    !container.contains(asElement(event.target)) ||
                    !that.shouldRender(boundingRect)) {
                    that.reset();
                    return;
                }
                that.setState({
                    end: end,
                    locked: true,
                }, function () {
                    var _a = that.state, start = _a.start, end = _a.end;
                    if (!start || !end) {
                        return;
                    }
                    if (isHTMLElement(event.target)) {
                        onSelection(startTarget, boundingRect, that.reset);
                        onDragEnd();
                    }
                });
            };
            var doc = container.ownerDocument;
            if (doc.body) {
                doc.body.addEventListener("mouseup", onMouseUp);
            }
        });
    };
    MouseSelection.prototype.shouldRender = function (boundingRect) {
        return boundingRect.width >= 1 && boundingRect.height >= 1;
    };
    MouseSelection.prototype.render = function () {
        var _this = this;
        var _a = this.state, start = _a.start, end = _a.end;
        return (React.createElement("div", { className: "MouseSelection-container", ref: function (node) {
                if (!node) {
                    return;
                }
                _this.root = node;
            } }, start && end ? (React.createElement("div", { className: "MouseSelection", style: this.getBoundingRect(start, end) })) : null));
    };
    return MouseSelection;
}(Component));
export default MouseSelection;
//# sourceMappingURL=MouseSelection.js.map