var getBoundingRect = function (clientRects) {
    var rects = Array.from(clientRects).map(function (rect) {
        var left = rect.left, top = rect.top, width = rect.width, height = rect.height, pageNumber = rect.pageNumber;
        var X0 = left;
        var X1 = left + width;
        var Y0 = top;
        var Y1 = top + height;
        return { X0: X0, X1: X1, Y0: Y0, Y1: Y1, pageNumber: pageNumber };
    });
    var firstPageNumber = Number.MAX_SAFE_INTEGER;
    rects.forEach(function (rect) {
        var _a;
        firstPageNumber = Math.min(firstPageNumber, (_a = rect.pageNumber) !== null && _a !== void 0 ? _a : firstPageNumber);
    });
    var rectsWithSizeOnFirstPage = rects.filter(function (rect) {
        return (rect.X0 > 0 || rect.X1 > 0 || rect.Y0 > 0 || rect.Y1 > 0) &&
            rect.pageNumber === firstPageNumber;
    });
    var optimal = rectsWithSizeOnFirstPage.reduce(function (res, rect) {
        return {
            X0: Math.min(res.X0, rect.X0),
            X1: Math.max(res.X1, rect.X1),
            Y0: Math.min(res.Y0, rect.Y0),
            Y1: Math.max(res.Y1, rect.Y1),
            pageNumber: firstPageNumber,
        };
    }, rectsWithSizeOnFirstPage[0]);
    var X0 = optimal.X0, X1 = optimal.X1, Y0 = optimal.Y0, Y1 = optimal.Y1, pageNumber = optimal.pageNumber;
    return {
        left: X0,
        top: Y0,
        width: X1 - X0,
        height: Y1 - Y0,
        pageNumber: pageNumber,
    };
};
export default getBoundingRect;
//# sourceMappingURL=get-bounding-rect.js.map