import optimizeClientRects from "./optimize-client-rects";
var isClientRectInsidePageRect = function (clientRect, pageRect) {
    if (clientRect.top < pageRect.top) {
        return false;
    }
    if (clientRect.bottom > pageRect.bottom) {
        return false;
    }
    if (clientRect.right > pageRect.right) {
        return false;
    }
    if (clientRect.left < pageRect.left) {
        return false;
    }
    return true;
};
var getClientRects = function (range, pages, shouldOptimize) {
    if (shouldOptimize === void 0) { shouldOptimize = true; }
    var clientRects = Array.from(range.getClientRects());
    var rects = [];
    for (var _i = 0, clientRects_1 = clientRects; _i < clientRects_1.length; _i++) {
        var clientRect = clientRects_1[_i];
        for (var _a = 0, pages_1 = pages; _a < pages_1.length; _a++) {
            var page = pages_1[_a];
            var pageRect = page.node.getBoundingClientRect();
            if (isClientRectInsidePageRect(clientRect, pageRect) &&
                clientRect.top >= 0 &&
                clientRect.bottom >= 0 &&
                clientRect.width > 0 &&
                clientRect.height > 0 &&
                clientRect.width < pageRect.width &&
                clientRect.height < pageRect.height) {
                var highlightedRect = {
                    top: clientRect.top + page.node.scrollTop - pageRect.top,
                    left: clientRect.left + page.node.scrollLeft - pageRect.left,
                    width: clientRect.width,
                    height: clientRect.height,
                    pageNumber: page.number,
                };
                rects.push(highlightedRect);
            }
        }
    }
    return shouldOptimize ? optimizeClientRects(rects) : rects;
};
export default getClientRects;
//# sourceMappingURL=get-client-rects.js.map