var sort = function (rects) {
    return rects.sort(function (A, B) {
        var top = (A.pageNumber || 0) * A.top - (B.pageNumber || 0) * B.top;
        if (top === 0) {
            return A.left - B.left;
        }
        return top;
    });
};
var overlaps = function (A, B) {
    return A.pageNumber === B.pageNumber &&
        A.left <= B.left &&
        B.left <= A.left + A.width;
};
var sameLine = function (A, B, yMargin) {
    if (yMargin === void 0) { yMargin = 5; }
    return A.pageNumber === B.pageNumber &&
        Math.abs(A.top - B.top) < yMargin &&
        Math.abs(A.height - B.height) < yMargin;
};
var inside = function (A, B) {
    return A.pageNumber === B.pageNumber &&
        A.top > B.top &&
        A.left > B.left &&
        A.top + A.height < B.top + B.height &&
        A.left + A.width < B.left + B.width;
};
var nextTo = function (A, B, xMargin) {
    if (xMargin === void 0) { xMargin = 10; }
    var Aright = A.left + A.width;
    var Bright = B.left + B.width;
    return (A.pageNumber === B.pageNumber &&
        A.left <= B.left &&
        Aright <= Bright &&
        B.left - Aright <= xMargin);
};
var extendWidth = function (A, B) {
    // extend width of A to cover B
    A.width = Math.max(B.width - A.left + B.left, A.width);
};
var optimizeClientRects = function (clientRects) {
    var rects = sort(clientRects);
    var toRemove = new Set();
    var firstPass = rects.filter(function (rect) {
        return rects.every(function (otherRect) {
            return !inside(rect, otherRect);
        });
    });
    var passCount = 0;
    while (passCount <= 2) {
        firstPass.forEach(function (A) {
            firstPass.forEach(function (B) {
                if (A === B || toRemove.has(A) || toRemove.has(B)) {
                    return;
                }
                if (!sameLine(A, B)) {
                    return;
                }
                if (overlaps(A, B)) {
                    extendWidth(A, B);
                    A.height = Math.max(A.height, B.height);
                    toRemove.add(B);
                }
                if (nextTo(A, B)) {
                    extendWidth(A, B);
                    toRemove.add(B);
                }
            });
        });
        passCount += 1;
    }
    return firstPass.filter(function (rect) { return !toRemove.has(rect); });
};
export default optimizeClientRects;
//# sourceMappingURL=optimize-client-rects.js.map