export var getDocument = function (elm) {
    return (elm || {}).ownerDocument || document;
};
export var getWindow = function (elm) {
    return (getDocument(elm) || {}).defaultView || window;
};
export var isHTMLElement = function (elm) {
    return elm instanceof HTMLElement || elm instanceof getWindow(elm).HTMLElement;
};
export var isHTMLCanvasElement = function (elm) {
    return elm instanceof HTMLCanvasElement ||
        elm instanceof getWindow(elm).HTMLCanvasElement;
};
export var asElement = function (x) { return x; };
export var getPageFromElement = function (target) {
    var node = asElement(target.closest(".page"));
    if (!node || !isHTMLElement(node)) {
        return null;
    }
    var number = Number(asElement(node).dataset.pageNumber);
    return { node: node, number: number };
};
export var getPagesFromRange = function (range) {
    var startParentElement = range.startContainer.parentElement;
    var endParentElement = range.endContainer.parentElement;
    if (!isHTMLElement(startParentElement) || !isHTMLElement(endParentElement)) {
        return [];
    }
    var startPage = getPageFromElement(asElement(startParentElement));
    var endPage = getPageFromElement(asElement(endParentElement));
    if (!(startPage === null || startPage === void 0 ? void 0 : startPage.number) || !(endPage === null || endPage === void 0 ? void 0 : endPage.number)) {
        return [];
    }
    if (startPage.number === endPage.number) {
        return [startPage];
    }
    if (startPage.number === endPage.number - 1) {
        return [startPage, endPage];
    }
    var pages = [];
    var currentPageNumber = startPage.number;
    var document = startPage.node.ownerDocument;
    while (currentPageNumber <= endPage.number) {
        var currentPage = getPageFromElement(document.querySelector("[data-page-number='" + currentPageNumber + "'"));
        if (currentPage) {
            pages.push(currentPage);
        }
    }
    return pages;
};
export var findOrCreateContainerLayer = function (container, className) {
    var doc = getDocument(container);
    var layer = container.querySelector("." + className);
    if (!layer) {
        layer = doc.createElement("div");
        layer.className = className;
        container.appendChild(layer);
    }
    return layer;
};
//# sourceMappingURL=pdfjs-dom.js.map